@@ -20,7 +20,9 @@ import subprocess
 import sys
 import tempfile
 
-import shade
+import openstack
+import openstack.config
+from openstack.cloud.exc import OpenStackCloudException
 from six.moves import urllib
 
 log = logging.getLogger(__name__)
@@ -52,12 +54,12 @@ def _filter_images(images, days=0, hide_public=False, ci_managed=True):
 
 def list(os_cloud, days=0, hide_public=False, ci_managed=True):
     """List images found according to parameters."""
-    cloud = shade.openstack_cloud(cloud=os_cloud)
+    cloud = openstack.connection.from_config(cloud=os_cloud)
     images = cloud.list_images()
 
     filtered_images = _filter_images(images, days, hide_public, ci_managed)
     for image in filtered_images:
-        print(image.name)
+        log.info(image.name)
 
 
 def cleanup(os_cloud, days=0, hide_public=False, ci_managed=True, clouds=None):
@@ -73,7 +75,7 @@ def cleanup(os_cloud, days=0, hide_public=False, ci_managed=True, clouds=None):
     """
 
     def _remove_images_from_cloud(images, cloud):
-        print("Removing {} images from {}.".format(len(images), cloud.cloud_config.name))
+        log.info("Removing {} images from {}.".format(len(images), cloud.cloud_config.name))
         project_info = cloud._get_project_info()
         for image in images:
 
@@ -93,28 +95,28 @@ def cleanup(os_cloud, days=0, hide_public=False, ci_managed=True, clouds=None):
 
             try:
                 result = cloud.delete_image(image.name)
-            except shade.exc.OpenStackCloudException as e:
+            except OpenStackCloudException as e:
                 if str(e).startswith("Multiple matches found for"):
-                    print("WARNING: {}. Skipping image...".format(str(e)))
+                    log.warning("{}. Skipping image...".format(str(e)))
                     continue
                 else:
-                    print("ERROR: Unexpected exception: {}".format(str(e)))
+                    log.error("Unexpected exception: {}".format(str(e)))
                     raise
 
             if not result:
-                print(
-                    'WARNING: Failed to remove "{}" from {}. Possibly already deleted.'.format(
+                log.warning(
+                    'Failed to remove "{}" from {}. Possibly already deleted.'.format(
                         image.name, cloud.cloud_config.name
                     )
                 )
             else:
-                print('Removed "{}" from {}.'.format(image.name, cloud.cloud_config.name))
+                log.info('Removed "{}" from {}.'.format(image.name, cloud.cloud_config.name))
 
-    cloud = shade.openstack_cloud(cloud=os_cloud)
+    cloud = openstack.connection.from_config(cloud=os_cloud)
     if clouds:
         cloud_list = []
         for c in clouds.split(","):
-            cloud_list.append(shade.openstack_cloud(cloud=c))
+            cloud_list.append(openstack.connection.from_config(cloud=c))
 
     images = cloud.list_images()
     filtered_images = _filter_images(images, days, hide_public, ci_managed)
@@ -201,7 +203,7 @@ def share(os_cloud, image, clouds):
 def upload(os_cloud, image, name, disk_format="raw"):
     """Upload image to openstack."""
     log.info('Uploading image {} with name "{}".'.format(image, name))
-    cloud = shade.openstack_cloud(cloud=os_cloud)
+    cloud = openstack.connection.from_config(cloud=os_cloud)
 
     if re.match(r"^http[s]?://", image):
         tmp = tempfile.NamedTemporaryFile(suffix=".img")
